Enum Request
#[non_exhaustive]pub enum Request {
Stop,
Destroy,
}wayland and Linux only.Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Stop
stop sending events
This request indicates that the client no longer wishes to receive events for new toplevels.
The Wayland protocol is asynchronous, meaning the compositor may send further toplevel events until the stop request is processed. The client should wait for a ext_foreign_toplevel_list_v1.finished event before destroying this object.
Destroy
destroy the ext_foreign_toplevel_list_v1 object
This request should be called either when the client will no longer use the ext_foreign_toplevel_list_v1 or after the finished event has been received to allow destruction of the object.
If a client wishes to destroy this object it should send a ext_foreign_toplevel_list_v1.stop request and wait for a ext_foreign_toplevel_list_v1.finished event, then destroy the handles and then this object.
This is a destructor, once received this object cannot be used any longer.
Implementations