Struct ExtForeignToplevelListV1
pub struct ExtForeignToplevelListV1 { /* private fields */ }wayland and Linux only.Expand description
list toplevels
A toplevel is defined as a surface with a role similar to xdg_toplevel. XWayland surfaces may be treated like toplevels in this protocol.
After a client binds the ext_foreign_toplevel_list_v1, each mapped toplevel window will be sent using the ext_foreign_toplevel_list_v1.toplevel event.
Clients which only care about the current state can perform a roundtrip after binding this global.
For each instance of ext_foreign_toplevel_list_v1, the compositor must create a new ext_foreign_toplevel_handle_v1 object for each mapped toplevel.
If a compositor implementation sends the ext_foreign_toplevel_list_v1.finished event after the global is bound, the compositor must not send any ext_foreign_toplevel_list_v1.toplevel events.
See also the Request enum for this interface.
Implementations
impl ExtForeignToplevelListV1
impl ExtForeignToplevelListV1
pub fn toplevel(&self, toplevel: &ExtForeignToplevelHandleV1)
pub fn toplevel(&self, toplevel: &ExtForeignToplevelHandleV1)
a toplevel has been created
This event is emitted whenever a new toplevel window is created. It is emitted for all toplevels, regardless of the app that has created them.
All initial properties of the toplevel (identifier, title, app_id) will be sent immediately after this event using the corresponding events for ext_foreign_toplevel_handle_v1. The compositor will use the ext_foreign_toplevel_handle_v1.done event to indicate when all data has been sent.
pub fn finished(&self)
pub fn finished(&self)
the compositor has finished with the toplevel manager
This event indicates that the compositor is done sending events to this object. The client should destroy the object. See ext_foreign_toplevel_list_v1.destroy for more information.
The compositor must not send any more toplevel events after this event.